Changelog
=========

[0.1.2] - December 1, 2025
--------------------------

- LeakDetector moved to juham-automation package.

  
[0.1.1] - November 28, 2025
---------------------------

- New unit tests added.
- Development status elevated to 3 - Alpha


[0.0.9] - June 1, 2025
------------------------

- Duplicate interval attribute, defined in both derived and the base class, fixed.
  The default time interval increased from 30 s to 10 min. 



[0.0.8] - April 18, 2025
------------------------

- Updated pyproject.toml to comply with the new SPDX expression for packaging standards


[0.0.7] - March 09, 2025
------------------------

- ``pyproject.tml`` dependencies updated, version elevated to 0.0.7


[0.0.3] - Februrary 23, 2025
----------------------------

- Debug messages removed.


[0.0.2] - January 11, 2025
--------------------------

- **Image comparison:** based trivial water leak detection plugged in. Simply compares
  the image agains the previous one, measures the diferences, and records the magnitude.
  If there is no leak then there should be periods where no changes are detected between
  record images.




[0.0.1] - January 5, 2025
-------------------------

- **First release:** 

